#
# VDR shutdown hook for nvram-wakeup - Tobias Grimm <tg@e-tobi.net>
# ----------------------------------
#
# This shutdown hook sets the wakeup time for the next timer using
# nvram-wakeup. If neccesary the shutdown command is modified to
# use a special shutdown strategy. Some mainboards i.e. need to reboot
# before power off, to enable a new wakeup time. (see nvram-wakeup doc)
#
# The special shutdown startegy must be installed as
#
#                     /usr/sbin/specialshutdown
#

NVRAMCMD=/usr/sbin/nvram-wakeup
SVDRPCMD=/usr/share/vdr/svdrpsend.pl
CHECKSCRIPT=/path/to/the/script

# read arguments for nvram-wakeup from conf-file
. /etc/vdr/vdr-addon-nvram-wakeup.conf

# Defaults:
[ -z "$ENABLED" ]           && export ENABLED="no"
[ -z "$COMMANDLINE" ]       && export COMMANDLINE=""
[ -z "$MAX_POWEROFF_TIME" ] && export MAX_POWEROFF_TIME=0

if [ $MAX_TRY_AGAIN -gt 0 ]
then
  # another script wants to retry shutdown later
  logger -t vdr-addon-nvram-wakup "nvram-wakup not called - shutdown suspended by other script"
  EXITCODE=0
else
  if [ $ENABLED = "no" ]
  then
    # vdr-addon-nvram-wakeup is disabled, so just exit
    logger -t vdr-addon-nvram-wakup "nvram-wakup functionality is disabled"
    EXITCODE=0
  else

    # calculate, at what time the machine should be powered on

    NOW=$((`date +%s`))

    if [ $MAX_POWEROFF_TIME -eq 0 ]
    then
      WAKEUPTIME=$1
    else
      WAKEUPTIME=`expr $NOW + $MAX_POWEROFF_TIME \* 60`
      if [ $WAKEUPTIME -gt $1 ] && [ $1 -gt 0 ]
      then
        WAKEUPTIME=$1
      fi
    fi

    # set wakeup time and check nvram-wakeup and check result

    logger -t vdr-addon-nvram-wakup "$NVRAMCMD -ls $WAKEUPTIME $COMMANDLINE"

    $NVRAMCMD -ls $WAKEUPTIME $COMMANDLINE

    case $PIPESTATUS in
         0) # all went ok - new date and time set
            logger -t vdr-addon-nvram-wakup "nvram-wakup: everything ok"
            EXITCODE=0
          ;;
         1) # all went ok - new date and time set.
            #
            # *** but we need to reboot. ***
            #
            # for some boards this is needed after every change.
            #
            # for some other boards, we only need this after changing the
            # status flag, i.e. from enabled to disabled or the other way.
          
        
            # For plan A - (Plan A is not supported anymore---see README)
            #
            # For plan B - (don't forget to install the modified kernel image first)
            #
          
            logger -t vdr-addon-nvram-wakup "nvram-wakup: everything ok - need to reboot first"

            if [ -x /usr/sbin/specialshutdown ]
            then
              SHUTDOWNCMD="/etc/init.d/vdr stop ; sleep 1 ; /usr/sbin/specialshutdown"
              EXITCODE=0
            else
              logger -t vdr-addon-nvram-wakup "nvram-wakup: A special shutdown strategy is requiered but not installed."
              EXITCODE=1    
	    fi
            ;;
         2) # something went wrong
            # don't do anything - just exit with status 1
 
            logger -t vdr-addon-nvram-wakup "nvram-wakup: could not set time, shutdown will be aborted"
            EXITCODE=1
            ;;
    esac
  fi
fi
